DynamicIconPlusPlatform class abstract
The interface that platform-specific implementations of DynamicIconPlus must extend.
- Inheritance
-
- Object
- PlatformInterface
- DynamicIconPlusPlatform
- Implementers
Constructors
- DynamicIconPlusPlatform()
- Constructs a DynamicIconPlusPlatform.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
supportsAlternateIcons
→ Future<
bool> -
Checks if the current platform supports dynamic icon switching.
no setter
Methods
-
getAlternateIconName(
) → Future< String?> -
Gets the currently active alternate icon name, or
nullif the default icon is active. -
getAvailableIcons(
) → Future< List< String> > - Gets all registered alternate icon names available in the app.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
resetToDefault(
{bool showAlert = true}) → Future< void> - Restores the default launcher icon.
-
setAlternateIconName(
String? iconName, {bool showAlert = true}) → Future< void> -
Sets the app icon to
iconName, or restores default icon ificonNameisnullor empty. -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance ↔ DynamicIconPlusPlatform
-
The default instance of DynamicIconPlusPlatform to use.
getter/setter pair